@@ -69,7 +69,8 @@ def basic_eval(evaluatable_rag, sample_size=200, qa_sample_size=100, top_k=None,
 
 def god_eval(encoder_name, sample_size=200, qa_sample_size=100, multi_hop_hardness_factor=0,
              judged=False, top_k=None, useTool=False, llm=None, reranker_name=None,tests=[],custom_data=None,
-             custom_project_name=None,wandb_group=None,multi_hop=True):
+             custom_project_name=None,wandb_group=None,multi_hop=True,encoder_query_prompt=None, encoder_doc_prompt=None):
+
     import MetaRagTool.Evaluations.TestManager as TestManager
     import MetaRagTool.Utils.MRUtils as MRUtils
     from MetaRagTool.Encoders import CrossEncoderReranker
@@ -79,7 +80,9 @@ def god_eval(encoder_name, sample_size=200, qa_sample_size=100, multi_hop_hardne
     ragConfig = MRUtils.Init(encoder_name=encoder_name, top_k=top_k, sample_size=sample_size,
                              qa_sample_size=qa_sample_size,
                              multi_hop_hardness_factor=multi_hop_hardness_factor, judged=judged, useTool=useTool,
-                             multi_hop=multi_hop,llm=llm,custom_data=custom_data,custom_project_name=custom_project_name,wandb_group=wandb_group)
+                             multi_hop=multi_hop,llm=llm,custom_data=custom_data,custom_project_name=custom_project_name,wandb_group=wandb_group,
+                             encoder_query_prompt=encoder_query_prompt, encoder_doc_prompt=encoder_doc_prompt
+                             )
 
     eval_k_base = [1, 5, 10, 15, 20, 30, 40, 50, 70, 100]
     eval_k_half = [1, 3, 5, 8, 12, 18, 25, 33, 42, 50]
