@@ -3,7 +3,7 @@ import weave
 
 
 class JudgeLLM:
-    def __init__(self,model_name=Gemini.GEMINI_2_FLASH_LIGHT,RequestPerMinute_limit=30):
+    def __init__(self,model_name=Gemini.GEMINI_2_FLASH,RequestPerMinute_limit=-1):
         sys_message = """You are an impartial judge evaluating answer quality.
         Your task is to determine if an answer correctly addresses a question based on the ground truth.
 
