@@ -71,7 +71,7 @@ class MetaRAG:
 
     def apply_best_config(self,text_has_proper_paragraphing=True):
         from MetaRagTool.Utils import get_best_config
-        bestConfig = get_best_config(text_has_proper_paragraphing=True)
+        bestConfig = get_best_config(text_has_proper_paragraphing=text_has_proper_paragraphing)
         self.apply_config(bestConfig)
 
 
